@@ -6,7 +6,7 @@ from collections import namedtuple
 
 from testfixtures.shouldraise import ShouldAssert
 from testfixtures.tests.sample1 import SampleClassA, SampleClassB, Slotted
-from .mock import Mock, call
+from testfixtures.mock import Mock, call
 from re import compile
 from testfixtures import (
     Comparison as C,
@@ -19,7 +19,7 @@ from testfixtures import (
 from testfixtures.compat import (
     class_type_name, exception_module, PY3, xrange,
     BytesLiteral, UnicodeLiteral,
-    PY2
+    PY2, PY_37_PLUS
 )
 from testfixtures.comparison import compare_sequence
 from unittest import TestCase
@@ -52,7 +52,7 @@ class CompareHelper(object):
             if message is not None:
                 # handy for debugging, but can't be relied on for tests!
                 compare(actual, expected=message, show_whitespace=True)
-                assert actual==message
+                assert actual == message
             else:
                 if not regex.match(actual):  # pragma: no cover
                     raise AssertionError(
@@ -100,6 +100,43 @@ class TestCompare(CompareHelper, TestCase):
             expected
             )
 
+    def test_bytes_different(self):
+        if PY2:
+            expected = (
+                "\n" 
+                "'12345678901'\n"
+                '!=\n'
+                "'12345678902'"
+            )
+        else:
+            expected = (
+                "\n" 
+                "b'12345678901'\n"
+                '!=\n'
+                "b'12345678902'"
+            )
+        self.check_raises(
+            BytesLiteral('12345678901'),
+            BytesLiteral('12345678902'),
+            expected
+            )
+
+    def test_bytes_same_strict(self):
+        compare(actual=b'', expected=b'', strict=True)
+
+    if PY3:
+        def test_moar_bytes_different(self):
+            self.check_raises(
+                actual=b'{"byte_pound":"b\'\\\\xa3\'"}',
+                expected=b'{"byte_pound":"b\\\'\\xa3\'"}',
+                message = (
+                    "\n"
+                    "b'{\"byte_pound\":\"b\\\\\\'\\\\xa3\\\'\"}' (expected)\n"
+                    '!=\n'
+                    "b'{\"byte_pound\":\"b\\\'\\\\\\\\xa3\\\'\"}' (actual)"
+                )
+            )
+
     def test_string_diff_short(self):
         self.check_raises(
             '\n'+('x'*9), '\n'+('y'*9),
@@ -165,10 +202,16 @@ class TestCompare(CompareHelper, TestCase):
     def test_exception_diff(self):
         e1 = ValueError('some message')
         e2 = ValueError('some other message')
-        self.check_raises(
-            e1, e2,
-            "ValueError('some message',) != ValueError('some other message',)"
-            )
+        if PY_37_PLUS:
+            self.check_raises(
+                e1, e2,
+                "ValueError('some message') != ValueError('some other message')"
+                )
+        else:
+            self.check_raises(
+                e1, e2,
+                "ValueError('some message',) != ValueError('some other message',)"
+                )
 
     def test_exception_diff_c_wrapper(self):
         e1 = ValueError('some message')
@@ -176,13 +219,14 @@ class TestCompare(CompareHelper, TestCase):
         self.check_raises(
             C(e1), e2,
             ("\n"
-             "<C(failed):{0}.ValueError>\n"
+             "<C(failed):{}.ValueError>\n"
              "attributes differ:\n"
              "'args': ('some message',) (Comparison) "
              "!= ('some other message',) (actual)\n"
              "</C>"
-             " != ValueError('some other message',)"
-             ).format(exception_module))
+             " != ValueError('some other message'{})"
+             ).format(exception_module,
+                      '' if PY_37_PLUS else ','))
 
     def test_sequence_long(self):
         self.check_raises(
@@ -1302,7 +1346,7 @@ b
 
     def test_invalid_zero_args(self):
         with ShouldRaise(TypeError(
-                'Exactly two objects needed, you supplied: []'
+                'Exactly two objects needed, you supplied:'
         )):
             compare()
 
@@ -1318,6 +1362,12 @@ b
         )):
             compare('x', 'y', 'z')
 
+    def test_invalid_because_of_typo(self):
+        with ShouldRaise(TypeError(
+                "Exactly two objects needed, you supplied: ['x'] {'expceted': 'z'}"
+        )):
+            compare('x', expceted='z')
+
     def test_dont_raise(self):
         self.assertEqual(compare('x', 'y', raises=False), "'x' != 'y'")
 
@@ -1415,29 +1465,11 @@ b
             "second:\n"
             "[call.bar(1, 3, x=7, y=4)]"
             "\n\n"
-            'While comparing [0]: mock.call not as expected:\n'
-            '\n'
-            "While comparing [0] function name: 'foo' != 'bar'\n"
-            '\n'
-            'While comparing [0] args: sequence not as expected:\n'
-            '\n'
-            'same:\n'
-            '(1,)\n'
-            '\n'
-            'first:\n'
-            '(2,)\n'
-            '\n'
-            'second:\n'
-            '(3,)\n'
-            '\n'
-            'While comparing [0] kw: dict not as expected:\n'
-            '\n'
-            'same:\n'
-            "['y']\n"
-            '\n'
-            'values differ:\n'
-            "'x': 3 != 7"
-            )
+            'While comparing [0]: \n'
+            "'call.foo(1, 2, x=3, y=4)'\n"
+            '!=\n'
+            "'call.bar(1, 3, x=7, y=4)'"
+        )
 
     def test_compare_arbitrary_nested_same(self):
         compare(SampleClassA([SampleClassB()]),
